Module smoothing

Module smoothing 

Time series smoothing and forecasting.

Exponential smoothing methods for level, trend, and seasonal decomposition of time series data.

Methods

References

  • Brown, R.G. (1956). Exponential Smoothing for Predicting Demand.
  • Holt, C.C. (1957). “Forecasting Seasonals and Trends by Exponentially Weighted Moving Averages”, ONR Memo 52.
  • Winters, P.R. (1960). “Forecasting Sales by Exponentially Weighted Moving Averages”, Management Science 6(3), pp. 324-342.

Structs

HoltLinear
Holt’s Linear Exponential Smoothing.
HoltResult
Result of Holt’s linear smoothing at each time step.
HoltWinters
Holt-Winters Triple Exponential Smoothing.
HoltWintersResult
Result of Holt-Winters smoothing.
SesResult
Result of simple exponential smoothing at each time step.
SimpleExponentialSmoothing
Simple Exponential Smoothing.

Enums

Seasonality
Seasonality type.