Module spc

Module spc 

Statistical Process Control (SPC) charts.

Provides control chart implementations for both variables and attributes data.

Variables Charts

  • XBarRChart — X-bar and Range chart for subgroup data (n=2..10)
  • XBarSChart — X-bar and Standard Deviation chart for subgroup data (n=2..10)
  • IndividualMRChart — Individual and Moving Range chart for individual observations

Attributes Charts

  • PChart — Proportion nonconforming (variable sample size)
  • NPChart — Count of nonconforming items (constant sample size)
  • CChart — Count of defects per unit (constant area of opportunity)
  • UChart — Defects per unit (variable area of opportunity)

Run Rules

References

  • Montgomery, D.C. (2019). Introduction to Statistical Quality Control, 8th ed.
  • ASTM E2587 — Standard Practice for Use of Control Charts
  • Nelson, L.S. (1984). “The Shewhart Control Chart — Tests for Special Causes”, Journal of Quality Technology 16(4), pp. 237-239.

Structs

CChart
Count of defects per unit (C) chart.
ChartPoint
A single point on a control chart.
ControlLimits
Control limits for a chart.
IndividualMRChart
Individual and Moving Range (I-MR) control chart.
NPChart
Count of nonconforming items (NP) chart.
NelsonRules
Nelson rules (8 rules, superset of Western Electric).
PChart
Proportion nonconforming (P) chart.
UChart
Defects per unit (U) chart.
Violation
A violation detected on the chart.
WesternElectricRules
Western Electric rules (4 rules).
XBarRChart
X-bar and Range (X-bar-R) control chart.
XBarSChart
X-bar and Standard Deviation (X-bar-S) control chart.

Enums

ViolationType
Types of control chart violations based on Nelson’s eight rules.

Traits

ControlChart
Trait for control charts that process subgroup or individual data.
RunRule
Trait for applying run rules to chart data.