GChart

Struct GChart 

pub struct GChart {
    pub g_bar: f64,
    pub points: Vec<GChartPoint>,
}
G chart (geometric distribution) result for rare-event monitoring.

Monitors the number of conforming units between consecutive defect events. Appropriate when the defect rate is very low (< 1%) and standard P/NP charts produce degenerate limits.

References

  • Kaminsky, F.C. et al. (1992). “Statistical control charts based on a geometric distribution”, Journal of Quality Technology 24(2), pp. 63-69.
  • Benneyan, J.C. (2001). “Number-Between g-Type Statistical Quality Control Charts for Healthcare Applications”, Health Care Management Science 4(4), pp. 305-318.
  • Woodall, W.H. (2006). “The Use of Control Charts in Health-Care and Public-Health Surveillance”, Journal of Quality Technology 38(2), pp. 89-104.

Fields

g_bar: f64

Mean inter-event conforming count (ḡ).

points: Vec<GChartPoint>

Per-observation chart points.