Statistical Process Control (SPC) charts.
Provides control chart implementations for both variables and attributes data.
Variables Charts
XBarRChart— X-bar and Range chart for subgroup data (n=2..10)XBarSChart— X-bar and Standard Deviation chart for subgroup data (n=2..10)IndividualMRChart— Individual and Moving Range chart for individual observations
Attributes Charts
PChart— Proportion nonconforming (variable sample size)NPChart— Count of nonconforming items (constant sample size)CChart— Count of defects per unit (constant area of opportunity)UChart— Defects per unit (variable area of opportunity)
Run Rules
WesternElectricRules— 4 classic run rulesNelsonRules— 8 rules (superset of Western Electric)
References
- Montgomery, D.C. (2019). Introduction to Statistical Quality Control, 8th ed.
- ASTM E2587 — Standard Practice for Use of Control Charts
- Nelson, L.S. (1984). “The Shewhart Control Chart — Tests for Special Causes”, Journal of Quality Technology 16(4), pp. 237-239.
Structs
- CChart
- Count of defects per unit (C) chart.
- Chart
Point - A single point on a control chart.
- Control
Limits - Control limits for a chart.
- GChart
- G chart (geometric distribution) result for rare-event monitoring.
- GChart
Point - A single data point on a G or T chart.
- IndividualMR
Chart - Individual and Moving Range (I-MR) control chart.
- Laney
Attribute Point - A single data point for a Laney P’ or U’ chart.
- LaneyP
Chart - Laney P’ chart result.
- LaneyU
Chart - Laney U’ chart result.
- NPChart
- Count of nonconforming items (NP) chart.
- Nelson
Rules - Nelson rules (8 rules, superset of Western Electric).
- PChart
- Proportion nonconforming (P) chart.
- TChart
- T chart (exponential distribution) result for rare-event monitoring.
- TChart
Point - A single data point on a T chart.
- UChart
- Defects per unit (U) chart.
- Violation
- A violation detected on the chart.
- Western
Electric Rules - Western Electric rules (4 rules).
- XBarR
Chart - X-bar and Range (X-bar-R) control chart.
- XBarS
Chart - X-bar and Standard Deviation (X-bar-S) control chart.
Enums
- Violation
Type - Types of control chart violations based on Nelson’s eight rules.
Traits
- Control
Chart - Trait for control charts that process subgroup or individual data.
- RunRule
- Trait for applying run rules to chart data.
Functions
- g_chart
- Compute the G chart from inter-event conforming counts.
- laney_
p_ chart - Compute the Laney P’ chart from
(defective_count, sample_size)pairs. - laney_
u_ chart - Compute the Laney U’ chart from
(defect_count, inspection_units)pairs. - t_chart
- Compute the T chart from inter-event times.