pub struct WesternElectricRules;Expand description
Western Electric rules (4 rules).
A subset of Nelson’s rules, these are the original run tests from the Western Electric Statistical Quality Control Handbook (1956):
- Any point beyond 3 sigma (Nelson Rule 1)
- 2 of 3 consecutive points beyond 2 sigma, same side (Nelson Rule 5)
- 4 of 5 consecutive points beyond 1 sigma, same side (Nelson Rule 6)
- 9 consecutive points on the same side of center line (Nelson Rule 2)